@@ -1,4 +1,5 @@
 import argparse
+import json
 from pathlib import Path
 from azureml.core import Run, Dataset
 
@@ -17,7 +18,6 @@ parser.add_argument('--save_datastore_path', type=str, help='save datastore path
 parser.add_argument('--save_dataset', type=str, help='save dataset')
 parser.add_argument('--chunk_index', type=str, help='index of the current chunk')
 
-
 # Get arguments from parser
 args = parser.parse_args()
 img_dir = args.img_dir
@@ -51,12 +51,27 @@ dir_list = [p for p in Path(output_jsons).iterdir() if p.is_dir()]
 for dir_path in dir_list:
     dir_name = dir_path.name
     source = str(data_output_dir_path / dir_name)
-    destination = str(Path(save_datastore_path) / dir_name)
-    dataset = Dataset.File.upload_directory(
-        src_dir=source, target=DataPath(dstore, destination), pattern="*",
+    dummy_path = str(data_output_dir_path / dir_name / 'dummy.json')
+    with open(dummy_path, 'w') as f:
+        json.dump({}, f, indent=2)
+
+    Dataset.File.upload_directory(
+        src_dir=source, target=DataPath(dstore, str(Path(save_datastore_path) / dir_name)), pattern="*",
         show_progress=True,
         overwrite=True
     )
 
+    subdir_list = [p for p in Path(source).iterdir() if p.is_dir()]
+
+    for subdir_path in subdir_list:
+        subdirname = subdir_path.name
+        destination = str(Path(save_datastore_path) / dir_name / subdirname)
+        sub_source = str(Path(subdir_path) / dir_name / subdirname)
+        Dataset.File.upload_directory(
+            src_dir=sub_source, target=DataPath(dstore, destination), pattern="*",
+            show_progress=True,
+            overwrite=True
+        )
+
 # End the run
 run.complete()
